@@ -6,33 +6,39 @@ framework.
 Usage:
     python internetison [address]
 """
-from SystemConfiguration import *
+from __future__ import print_function
+from SystemConfiguration import kSCNetworkFlagsTransientConnection, kSCNetworkFlagsReachable
+from SystemConfiguration import kSCNetworkFlagsConnectionRequired, kSCNetworkFlagsConnectionAutomatic
+from SystemConfiguration import kSCNetworkFlagsInterventionRequired, kSCNetworkFlagsIsLocalAddress
+from SystemConfiguration import kSCNetworkFlagsIsDirect, SCNetworkReachabilityCreateWithAddress
+from SystemConfiguration import SCNetworkReachabilitySetCallback, SCNetworkReachabilityGetFlags
+from SystemConfiguration import SCNetworkReachabilityScheduleWithRunLoop
+from Cocoa import CFRunLoopGetCurrent, CFRunLoopStop, CFRunLoopRun
 import socket, sys
 
 def resultAvailable(target, flags, info):
-    print "got network reachability status for %s:"%(info,)
+    print("got network reachability status for %s:"%(info,))
 
     if flags & kSCNetworkFlagsTransientConnection:
-        print "- transient connection"
+        print("- transient connection")
 
     if flags &  kSCNetworkFlagsReachable:
-        print "- reachable"
+        print("- reachable")
 
     if flags &  kSCNetworkFlagsConnectionRequired:
-        print "- connection required"
+        print("- connection required")
 
     if flags &  kSCNetworkFlagsConnectionAutomatic:
-        print "- connection automatic"
+        print("- connection automatic")
 
     if flags &  kSCNetworkFlagsInterventionRequired:
-        print "- user intervention required"
+        print("- user intervention required")
 
     if flags &  kSCNetworkFlagsIsLocalAddress:
-        print "- local interface"
+        print("- local interface")
 
     if flags &  kSCNetworkFlagsIsDirect:
-        print "- directly attached network"
-
+        print("- directly attached network")
 
     # And stop the program:
     loop = CFRunLoopGetCurrent()
@@ -43,7 +49,7 @@ def main():
     if len(sys.argv) >= 2:
         addr = socket.gethostbyname(sys.argv[1])
     else:
-        addr = '82.94.237.218' # www.python.org
+        addr = "82.94.237.218" # www.python.org
 
     loop = CFRunLoopGetCurrent()
 
